import {select,csv,scaleTime,scaleLinear,
       axisBottom,axisLeft,extent} from 'd3';

const svg= select('svg');
const width= +svg.attr('width');
const height= +svg.attr('height');

const render= data=>{

  const margin = { top: 60, right: 40, bottom: 80, left: 100 };
  const innerHeight= height -margin.top-margin.bottom;
  const innerWidth= width- margin.left- margin.right;
  const title='Temperature in SanFrancisco';
  const circleRadius=6;
  
  const yLabel='Temperature';
  const xLabel='Time';
  
  const xValue= d=>d.timestamp;
  const yValue= d=>d.temperature;
  
  const g= svg.append('g')
  					.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xScale= scaleTime()
  								.domain(extent(data,xValue))
  								.range([0,innerWidth])
  								.nice();	
  const yScale= scaleLinear()
  								.domain(extent(data,yValue))
  								.range([innerHeight,0])
  								.nice();
  const xAxis= axisBottom(xScale)
  							.tickSize(innerHeight)
  							.tickPadding(13);
  
  const yAxis= axisLeft(yScale)
  								.tickSize(-innerWidth)
  								.tickPadding(15);
  
  const xAxisG= g.append('g').call(xAxis)
  								.attr('transform',`translate(0，${innerHeight})`);
  
  const yAxisG= g.append('g').call(yAxis);
  			
  
  g.selectAll('circle').data(data)
  		.enter().append('circle')
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  				.attr('class','label')
  				.attr('transform','rotate(-90)')
  				.attr('x',-300)
  				.attr('y',-55)
  				.attr('test-anchor','middle')
  				.text(yLabel);
  
  xAxisG.select('.domain').remove();
  
	xAxisG.append('text')
      .attr('class', 'label')
      .attr('y', 440)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xLabel);
 
  
  g.append('text')
  			.attr('class','title')
  			.attr('y',-17)
  			.text(title);
}


csv('https://vizhub.com/thembones79/datasets/temperature-in-san-francisco.csv')
	.then(data=>{
		console.log(data);
  	data.forEach(d=>{
    	d.temperature= +d.temperature;
      d.timestamp= new Date(d.timestamp);
    });
  render(data);
})